.. _faq:

FAQ
===

How can I get help?
-------------------

See :ref:`get help`.

I can not install/run MAnorm on Windows
---------------------------------------

Starting from version 1.2.0, MAnorm does not support Windows any more. This is because MAnorm uses
`pysam`_ as a dependency to parse SAM/BAM files. There may be some compiling issues with Windows
and we are sorry about that.

The Python version I use is not the same as MAnorm requires
-----------------------------------------------------------

MAnorm requires Python 3.6+. If you are not using these versions, it is recommended to
create a separated Python environment with `virtualenv`_ or `conda`_.


Can I use MAnorm to analyze samples with replicates?
----------------------------------------------------

Basically, MAnorm is designed to normalize samples without replicates for each condition.
And a more complicated statistic model `MAnorm2`_ is designed to capture the variation among replicates.
If you have multiple samples for each condition, please use `MAnorm2`_.

The format of my peak/read file is not supported by MAnorm
----------------------------------------------------------

At present, MAnorm supports many standard formats generated by commonly used peak callers or
alignment tools. If your format is not supported, please manually covert it to any supported format
or open an `issue`_ to ask for support.

What are *M* values and *A* values in MAnorm?
---------------------------------------------

The *M* value in MAnorm is the *log*:sub:`2` fold change of normalized read densities between sample 1
and sample 2, which quantitatively indicates the difference of the ChIP-seq signal in a specific peak
region. And the *A* value is the averaged read density of two ChIP-seq samples under comparison.

I am confused about P values in MAnorm
--------------------------------------

The P value that MAnorm gives is not a strict *p-value* in statistics which shows the probability of
obtaining a result which equals to or is more extreme than the observation when the null hypothesis is true.
Instead, it is a conditional probability which technically tells how likely it is to observe *x* reads
in sample 1 and *y* reads in sample 2 on a peak region given the sum of *x+y*.
For more information, please refer to the manuscript of MAnorm.

.. _pysam: https://pypi.org/project/pysam/
.. _virtualenv: https://pypi.org/project/virtualenv/
.. _conda: https://conda.io
.. _MAnorm2: https://github.com/tushiqi/MAnorm2
.. _issue: https://github.com/shao-lab/MAnorm/issues
